
from composite_field.rest_framework_support import CompositeFieldSerializer
from rest_framework import serializers


from imagedb.models import Instrument, NispDetector, Astrometry, NispRawFrame

class InstrumentSerializer(serializers.ModelSerializer):
  class Meta:
    model = Instrument
    fields = '__all__'
    
    
class AstrometrySerializer(serializers.ModelSerializer):
  ctype1 = CompositeFieldSerializer()
  ctype2 = CompositeFieldSerializer()
  
  class Meta:
    model = Astrometry
    exclude = ('ctype1_coordinateType',
               'ctype1_projectionType',
               'ctype2_coordinateType',
               'ctype2_projectionType')    

    
class NispDetectorSerializer(serializers.ModelSerializer):
  astrometry = AstrometrySerializer(read_only = True)

  class Meta:
    model = NispDetector
    exclude = ('rawFrame',)
    
    
class NispRawFrameSerializer(serializers.ModelSerializer):
  detectors = NispDetectorSerializer(many = True, read_only = True)
  commandedPointing = CompositeFieldSerializer()
  imageType = CompositeFieldSerializer()

  class Meta:
    model = NispRawFrame
    exclude = ('commandedPointing_rightAscension',
               'commandedPointing_declination',
               'commandedPointing_orientation',
               'imageType_category',
               'imageType_firstType',
               'imageType_secondType')
    depth = 2
    
    
